<?php

namespace Drp\SimpleCms\Generators\Crud;

use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;

class Core
{
    public static function prepare(): void
    {
        collect(config('simple_cms.generator.directories'))->each(function ($directory): void {
            if (File::exists($directory)) {
                return;
            }

            File::makeDirectory($directory);
        });

        if (File::exists(base_path('storage/app/templates/controllers'))) {
            return;
        }

        File::copyDirectory(__DIR__.'/templates', Storage::path('templates'));
    }

    public static function create(
        string $templatePath,
        string $filePath,
        string $name
    ): string {
        $replace = self::getReplacements($name);

        file_put_contents(
            $filePath,
            str_replace(array_keys($replace), $replace, file_get_contents($templatePath))
        );

        return $filePath;
    }

    public static function getReplacements(string $name): array
    {
        return [
            '__simple__' => strtolower($name),
            '__Simple__' => ucfirst($name),
            '__Simples__' => Str::plural(ucfirst($name)),
            '__simples__' => Str::plural(strtolower($name)),
        ];
    }

    public static function shouldModify(string $filename, string $needle): bool
    {
        return strpos(file_get_contents($filename), $needle) === false;
    }
}
